Class: Google::Apis::AdminReportsV1::Activity::Actor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb

Overview

User doing the action.

Defined Under Namespace

Classes: ApplicationInfo

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Actor

Returns a new instance of Actor.



169
170
171
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_infoGoogle::Apis::AdminReportsV1::Activity::Actor::ApplicationInfo

Details of the application that was the actor for the activity. Corresponds to the JSON property applicationInfo



143
144
145
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 143

def application_info
  @application_info
end

#caller_typeString

The type of actor. Corresponds to the JSON property callerType

Returns:

  • (String)


148
149
150
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 148

def caller_type
  @caller_type
end

#emailString

The primary email address of the actor. May be absent if there is no email address associated with the actor. Corresponds to the JSON property email

Returns:

  • (String)


154
155
156
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 154

def email
  @email
end

#keyString

Only present when callerType is KEY. Can be the consumer_key of the requestor for OAuth 2LO API requests or an identifier for robot accounts. Corresponds to the JSON property key

Returns:

  • (String)


160
161
162
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 160

def key
  @key
end

#profile_idString

The unique Google Workspace profile ID of the actor. This value might be absent if the actor is not a Google Workspace user, or may be the number 105250506097979753968 which acts as a placeholder ID. Corresponds to the JSON property profileId

Returns:

  • (String)


167
168
169
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 167

def profile_id
  @profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



174
175
176
177
178
179
180
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 174

def update!(**args)
  @application_info = args[:application_info] if args.key?(:application_info)
  @caller_type = args[:caller_type] if args.key?(:caller_type)
  @email = args[:email] if args.key?(:email)
  @key = args[:key] if args.key?(:key)
  @profile_id = args[:profile_id] if args.key?(:profile_id)
end