Class: Google::Apis::AdminReportsV1::Activity::Actor::ApplicationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb

Overview

Details of the application that was the actor for the activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApplicationInfo

Returns a new instance of ApplicationInfo.



221
222
223
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_nameString

Name of the application used to perform the action. Corresponds to the JSON property applicationName

Returns:

  • (String)


208
209
210
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 208

def application_name
  @application_name
end

#impersonationBoolean Also known as: impersonation?

Whether the application was impersonating a user. Corresponds to the JSON property impersonation

Returns:

  • (Boolean)


213
214
215
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 213

def impersonation
  @impersonation
end

#oauth_client_idString

OAuth client id of the third party application used to perform the action. Corresponds to the JSON property oauthClientId

Returns:

  • (String)


219
220
221
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 219

def oauth_client_id
  @oauth_client_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



226
227
228
229
230
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 226

def update!(**args)
  @application_name = args[:application_name] if args.key?(:application_name)
  @impersonation = args[:impersonation] if args.key?(:impersonation)
  @oauth_client_id = args[:oauth_client_id] if args.key?(:oauth_client_id)
end