Class: Google::Apis::AdminReportsV1::Activity::Event::Parameter
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::Activity::Event::Parameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Defined Under Namespace
Classes: MessageValue, MultiMessageValue
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Boolean value of the parameter.
-
#int_value ⇒ Fixnum
Integer value of the parameter.
-
#message_value ⇒ Google::Apis::AdminReportsV1::Activity::Event::Parameter::MessageValue
Nested parameter value pairs associated with this parameter.
-
#multi_int_value ⇒ Array<Fixnum>
Integer values of the parameter.
-
#multi_message_value ⇒ Array<Google::Apis::AdminReportsV1::Activity::Event::Parameter::MultiMessageValue>
List of
messageValueobjects. -
#multi_value ⇒ Array<String>
String values of the parameter.
-
#name ⇒ String
The name of the parameter.
-
#value ⇒ String
String value of the parameter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Parameter
constructor
A new instance of Parameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Parameter
Returns a new instance of Parameter.
342 343 344 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Boolean value of the parameter.
Corresponds to the JSON property boolValue
301 302 303 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 301 def bool_value @bool_value end |
#int_value ⇒ Fixnum
Integer value of the parameter.
Corresponds to the JSON property intValue
307 308 309 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 307 def int_value @int_value end |
#message_value ⇒ Google::Apis::AdminReportsV1::Activity::Event::Parameter::MessageValue
Nested parameter value pairs associated with this parameter. Complex value
type for a parameter are returned as a list of parameter values. For example,
the address parameter may have a value as [parameter: [name: city, value:
abc]]
Corresponds to the JSON property messageValue
315 316 317 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 315 def @message_value end |
#multi_int_value ⇒ Array<Fixnum>
Integer values of the parameter.
Corresponds to the JSON property multiIntValue
320 321 322 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 320 def multi_int_value @multi_int_value end |
#multi_message_value ⇒ Array<Google::Apis::AdminReportsV1::Activity::Event::Parameter::MultiMessageValue>
List of messageValue objects.
Corresponds to the JSON property multiMessageValue
325 326 327 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 325 def @multi_message_value end |
#multi_value ⇒ Array<String>
String values of the parameter.
Corresponds to the JSON property multiValue
330 331 332 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 330 def multi_value @multi_value end |
#name ⇒ String
The name of the parameter.
Corresponds to the JSON property name
335 336 337 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 335 def name @name end |
#value ⇒ String
String value of the parameter.
Corresponds to the JSON property value
340 341 342 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 340 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
347 348 349 350 351 352 353 354 355 356 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 347 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @int_value = args[:int_value] if args.key?(:int_value) @message_value = args[:message_value] if args.key?(:message_value) @multi_int_value = args[:multi_int_value] if args.key?(:multi_int_value) @multi_message_value = args[:multi_message_value] if args.key?(:multi_message_value) @multi_value = args[:multi_value] if args.key?(:multi_value) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |