Class: Google::Apis::AdminReportsV1::Activity::Event::SensitiveParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb

Defined Under Namespace

Classes: MessageValue, MultiMessageValue

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SensitiveParameter

Returns a new instance of SensitiveParameter.



448
449
450
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Boolean value of the parameter. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


407
408
409
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 407

def bool_value
  @bool_value
end

#int_valueFixnum

Integer value of the parameter. Corresponds to the JSON property intValue

Returns:

  • (Fixnum)


413
414
415
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 413

def int_value
  @int_value
end

#message_valueGoogle::Apis::AdminReportsV1::Activity::Event::SensitiveParameter::MessageValue

Nested parameter value pairs associated with this parameter. Complex value type for a parameter are returned as a list of parameter values. For example, the address parameter may have a value as [parameter: [name: city, value: abc]] Corresponds to the JSON property messageValue



421
422
423
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 421

def message_value
  @message_value
end

#multi_int_valueArray<Fixnum>

Integer values of the parameter. Corresponds to the JSON property multiIntValue

Returns:

  • (Array<Fixnum>)


426
427
428
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 426

def multi_int_value
  @multi_int_value
end

#multi_message_valueArray<Google::Apis::AdminReportsV1::Activity::Event::SensitiveParameter::MultiMessageValue>

List of messageValue objects. Corresponds to the JSON property multiMessageValue



431
432
433
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 431

def multi_message_value
  @multi_message_value
end

#multi_valueArray<String>

String values of the parameter. Corresponds to the JSON property multiValue

Returns:

  • (Array<String>)


436
437
438
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 436

def multi_value
  @multi_value
end

#nameString

The name of the parameter. Corresponds to the JSON property name

Returns:

  • (String)


441
442
443
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 441

def name
  @name
end

#valueString

String value of the parameter. Corresponds to the JSON property value

Returns:

  • (String)


446
447
448
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 446

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



453
454
455
456
457
458
459
460
461
462
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 453

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @int_value = args[:int_value] if args.key?(:int_value)
  @message_value = args[:message_value] if args.key?(:message_value)
  @multi_int_value = args[:multi_int_value] if args.key?(:multi_int_value)
  @multi_message_value = args[:multi_message_value] if args.key?(:multi_message_value)
  @multi_value = args[:multi_value] if args.key?(:multi_value)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end