Class: Google::Apis::AdminReportsV1::AppliedLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb

Overview

Details of the label applied on the resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppliedLabel

Returns a new instance of AppliedLabel.



730
731
732
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_valuesArray<Google::Apis::AdminReportsV1::FieldValue>

List of fields which are part of the label and have been set by the user. If label has a field which was not set by the user, it would not be present in this list. Corresponds to the JSON property fieldValues



712
713
714
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 712

def field_values
  @field_values
end

#idString

Identifier of the label - Only the label id, not the full OnePlatform resource name. Corresponds to the JSON property id

Returns:

  • (String)


718
719
720
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 718

def id
  @id
end

#reasonGoogle::Apis::AdminReportsV1::Reason

The reason why the label/field was applied. Corresponds to the JSON property reason



723
724
725
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 723

def reason
  @reason
end

#titleString

Title of the label Corresponds to the JSON property title

Returns:

  • (String)


728
729
730
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 728

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



735
736
737
738
739
740
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 735

def update!(**args)
  @field_values = args[:field_values] if args.key?(:field_values)
  @id = args[:id] if args.key?(:id)
  @reason = args[:reason] if args.key?(:reason)
  @title = args[:title] if args.key?(:title)
end