Class: Google::Apis::AdminReportsV1::OwnerIdentity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb

Overview

Identity details of the owner of the resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OwnerIdentity

Returns a new instance of OwnerIdentity.



1227
1228
1229
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_identityGoogle::Apis::AdminReportsV1::CustomerIdentity

Identity of the Google Workspace customer who owns the resource. Corresponds to the JSON property customerIdentity



1210
1211
1212
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1210

def customer_identity
  @customer_identity
end

#group_identityGoogle::Apis::AdminReportsV1::GroupIdentity

Identity of the group who owns the resource. Corresponds to the JSON property groupIdentity



1215
1216
1217
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1215

def group_identity
  @group_identity
end

#shared_drive_identityGoogle::Apis::AdminReportsV1::SharedDriveIdentity

Identity of the shared drive who owns the resource. Corresponds to the JSON property sharedDriveIdentity



1220
1221
1222
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1220

def shared_drive_identity
  @shared_drive_identity
end

#user_identityGoogle::Apis::AdminReportsV1::UserIdentity

Identity of the user who owns the resource. Corresponds to the JSON property userIdentity



1225
1226
1227
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1225

def user_identity
  @user_identity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1232
1233
1234
1235
1236
1237
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1232

def update!(**args)
  @customer_identity = args[:customer_identity] if args.key?(:customer_identity)
  @group_identity = args[:group_identity] if args.key?(:group_identity)
  @shared_drive_identity = args[:shared_drive_identity] if args.key?(:shared_drive_identity)
  @user_identity = args[:user_identity] if args.key?(:user_identity)
end