Class: Google::Apis::AdminReportsV1::ResourceDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb

Overview

Details of the resource on which the action was performed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceDetails

Returns a new instance of ResourceDetails.



1290
1291
1292
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_labelsArray<Google::Apis::AdminReportsV1::AppliedLabel>

List of labels applied on the resource Corresponds to the JSON property appliedLabels



1260
1261
1262
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1260

def applied_labels
  @applied_labels
end

#idString

Identifier of the resource, such as a doc_id for a Drive document, a conference_id for a Meet conference, or a "gaia_id/rfc2822_message_id" for an email. Corresponds to the JSON property id

Returns:

  • (String)


1267
1268
1269
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1267

def id
  @id
end

#owner_detailsGoogle::Apis::AdminReportsV1::OwnerDetails

Details of the owner of the resource. Corresponds to the JSON property ownerDetails



1272
1273
1274
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1272

def owner_details
  @owner_details
end

#relationString

Defines relationship of the resource to the events Corresponds to the JSON property relation

Returns:

  • (String)


1277
1278
1279
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1277

def relation
  @relation
end

#titleString

Title of the resource. For instance, in case of a drive document, this would be the title of the document. In case of an email, this would be the subject. Corresponds to the JSON property title

Returns:

  • (String)


1283
1284
1285
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1283

def title
  @title
end

#typeString

Type of the resource - document, email, chat message Corresponds to the JSON property type

Returns:

  • (String)


1288
1289
1290
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1288

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1295
1296
1297
1298
1299
1300
1301
1302
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1295

def update!(**args)
  @applied_labels = args[:applied_labels] if args.key?(:applied_labels)
  @id = args[:id] if args.key?(:id)
  @owner_details = args[:owner_details] if args.key?(:owner_details)
  @relation = args[:relation] if args.key?(:relation)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end