Class: Google::Apis::AdminReportsV1::UsageReports::Warning
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::UsageReports::Warning
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Defined Under Namespace
Classes: Datum
Instance Attribute Summary collapse
-
#code ⇒ String
Machine readable code or warning type.
-
#data ⇒ Array<Google::Apis::AdminReportsV1::UsageReports::Warning::Datum>
Key-value pairs to give detailed information on the warning.
-
#message ⇒ String
The human readable messages for a warning are: - Data is not available warning - Sorry, data for date yyyy-mm-dd for application "
application name" is not available.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Warning
constructor
A new instance of Warning.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Warning
Returns a new instance of Warning.
1411 1412 1413 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Machine readable code or warning type. The warning code value is 200.
Corresponds to the JSON property code
1395 1396 1397 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1395 def code @code end |
#data ⇒ Array<Google::Apis::AdminReportsV1::UsageReports::Warning::Datum>
Key-value pairs to give detailed information on the warning.
Corresponds to the JSON property data
1400 1401 1402 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1400 def data @data end |
#message ⇒ String
The human readable messages for a warning are: - Data is not available warning
- Sorry, data for date yyyy-mm-dd for application "
application name" is not available. - Partial data is available warning - Data for date yyyy-mm-dd for application "application name" is not available right now, please try again after a few hours. Corresponds to the JSON propertymessage
1409 1410 1411 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1409 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1416 1417 1418 1419 1420 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1416 def update!(**args) @code = args[:code] if args.key?(:code) @data = args[:data] if args.key?(:data) @message = args[:message] if args.key?(:message) end |