Class: Google::Apis::AdminReportsV1::UsageReports::Warning::Datum

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Datum

Returns a new instance of Datum.



1544
1545
1546
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Key associated with a key-value pair to give detailed information on the warning. Corresponds to the JSON property key

Returns:

  • (String)


1536
1537
1538
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1536

def key
  @key
end

#valueString

Value associated with a key-value pair to give detailed information on the warning. Corresponds to the JSON property value

Returns:

  • (String)


1542
1543
1544
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1542

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1549
1550
1551
1552
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1549

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end