Class: Google::Apis::AdminReportsV1::Activity
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::Activity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Overview
JSON template for the activity resource.
Defined Under Namespace
Instance Attribute Summary collapse
-
#actor ⇒ Google::Apis::AdminReportsV1::Activity::Actor
User doing the action.
-
#etag ⇒ String
ETag of the entry.
-
#events ⇒ Array<Google::Apis::AdminReportsV1::Activity::Event>
Activity events in the report.
-
#id ⇒ Google::Apis::AdminReportsV1::Activity::Id
Unique identifier for each activity record.
-
#ip_address ⇒ String
IP address of the user doing the action.
-
#kind ⇒ String
The type of API resource.
-
#network_info ⇒ Google::Apis::AdminReportsV1::ActivityNetworkInfo
Network information of the user doing the action.
-
#owner_domain ⇒ String
This is the domain that is affected by the report's event.
-
#resource_details ⇒ Array<Google::Apis::AdminReportsV1::ResourceDetails>
Details of the resource on which the action was performed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Activity
constructor
A new instance of Activity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Activity
Returns a new instance of Activity.
119 120 121 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actor ⇒ Google::Apis::AdminReportsV1::Activity::Actor
User doing the action.
Corresponds to the JSON property actor
71 72 73 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 71 def actor @actor end |
#etag ⇒ String
ETag of the entry.
Corresponds to the JSON property etag
76 77 78 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 76 def etag @etag end |
#events ⇒ Array<Google::Apis::AdminReportsV1::Activity::Event>
Activity events in the report.
Corresponds to the JSON property events
81 82 83 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 81 def events @events end |
#id ⇒ Google::Apis::AdminReportsV1::Activity::Id
Unique identifier for each activity record.
Corresponds to the JSON property id
86 87 88 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 86 def id @id end |
#ip_address ⇒ String
IP address of the user doing the action. This is the Internet Protocol (IP)
address of the user when logging into Google Workspace, which may or may not
reflect the user's physical location. For example, the IP address can be the
user's proxy server's address or a virtual private network (VPN) address. The
API supports IPv4 and IPv6.
Corresponds to the JSON property ipAddress
95 96 97 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 95 def ip_address @ip_address end |
#kind ⇒ String
The type of API resource. For an activity report, the value is audit#activity
.
Corresponds to the JSON property kind
101 102 103 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 101 def kind @kind end |
#network_info ⇒ Google::Apis::AdminReportsV1::ActivityNetworkInfo
Network information of the user doing the action.
Corresponds to the JSON property networkInfo
106 107 108 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 106 def network_info @network_info end |
#owner_domain ⇒ String
This is the domain that is affected by the report's event. For example domain
of Admin console or the Drive application's document owner.
Corresponds to the JSON property ownerDomain
112 113 114 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 112 def owner_domain @owner_domain end |
#resource_details ⇒ Array<Google::Apis::AdminReportsV1::ResourceDetails>
Details of the resource on which the action was performed.
Corresponds to the JSON property resourceDetails
117 118 119 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 117 def resource_details @resource_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 124 def update!(**args) @actor = args[:actor] if args.key?(:actor) @etag = args[:etag] if args.key?(:etag) @events = args[:events] if args.key?(:events) @id = args[:id] if args.key?(:id) @ip_address = args[:ip_address] if args.key?(:ip_address) @kind = args[:kind] if args.key?(:kind) @network_info = args[:network_info] if args.key?(:network_info) @owner_domain = args[:owner_domain] if args.key?(:owner_domain) @resource_details = args[:resource_details] if args.key?(:resource_details) end |