Class: Google::Apis::AdminReportsV1::Activity::Event
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::Activity::Event
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Defined Under Namespace
Classes: Parameter, SensitiveParameter
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the event.
-
#parameters ⇒ Array<Google::Apis::AdminReportsV1::Activity::Event::Parameter>
Parameter value pairs for various applications.
-
#resource_ids ⇒ Array<String>
Resource ids associated with the event.
-
#sensitive_parameters ⇒ Array<Google::Apis::AdminReportsV1::Activity::Event::SensitiveParameter>
Includes sensitive parameter value pairs for various applications.
-
#status ⇒ Google::Apis::AdminReportsV1::ActivityEventsStatus
Status of the event.
-
#type ⇒ String
Type of event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Event
constructor
A new instance of Event.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Event
Returns a new instance of Event.
280 281 282 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the event. This is the specific name of the activity reported by the
API. And each eventName is related to a specific Google Workspace service or
feature which the API organizes into types of events. For eventName request
parameters in general: - If no eventName is given, the report returns all
possible instances of an eventName. - When you request an eventName, the
API's response returns all activities which contain that eventName. For more
information about eventName properties, see the list of event names for
various applications above in applicationName.
Corresponds to the JSON property name
248 249 250 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 248 def name @name end |
#parameters ⇒ Array<Google::Apis::AdminReportsV1::Activity::Event::Parameter>
Parameter value pairs for various applications. For more information about
eventName parameters, see the list of event names for various applications
above in applicationName.
Corresponds to the JSON property parameters
255 256 257 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 255 def parameters @parameters end |
#resource_ids ⇒ Array<String>
Resource ids associated with the event.
Corresponds to the JSON property resourceIds
260 261 262 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 260 def resource_ids @resource_ids end |
#sensitive_parameters ⇒ Array<Google::Apis::AdminReportsV1::Activity::Event::SensitiveParameter>
Includes sensitive parameter value pairs for various applications.
Corresponds to the JSON property sensitiveParameters
265 266 267 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 265 def sensitive_parameters @sensitive_parameters end |
#status ⇒ Google::Apis::AdminReportsV1::ActivityEventsStatus
Status of the event. Note: Not all events have status.
Corresponds to the JSON property status
270 271 272 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 270 def status @status end |
#type ⇒ String
Type of event. The Google Workspace service or feature that an administrator
changes is identified in the type property which identifies an event using
the eventName property. For a full list of the API's type categories, see
the list of event names for various applications above in applicationName.
Corresponds to the JSON property type
278 279 280 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 278 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
285 286 287 288 289 290 291 292 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 285 def update!(**args) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @resource_ids = args[:resource_ids] if args.key?(:resource_ids) @sensitive_parameters = args[:sensitive_parameters] if args.key?(:sensitive_parameters) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |