Class: Google::Apis::AdminReportsV1::Activity::Event

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb

Defined Under Namespace

Classes: Parameter

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Event

Returns a new instance of Event.



256
257
258
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the event. This is the specific name of the activity reported by the API. And each eventName is related to a specific Google Workspace service or feature which the API organizes into types of events. For eventName request parameters in general: - If no eventName is given, the report returns all possible instances of an eventName. - When you request an eventName, the API's response returns all activities which contain that eventName. For more information about eventName properties, see the list of event names for various applications above in applicationName. Corresponds to the JSON property name

Returns:

  • (String)


229
230
231
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 229

def name
  @name
end

#parametersArray<Google::Apis::AdminReportsV1::Activity::Event::Parameter>

Parameter value pairs for various applications. For more information about eventName parameters, see the list of event names for various applications above in applicationName. Corresponds to the JSON property parameters



236
237
238
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 236

def parameters
  @parameters
end

#resource_idsArray<String>

Resource ids associated with the event. Corresponds to the JSON property resourceIds

Returns:

  • (Array<String>)


241
242
243
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 241

def resource_ids
  @resource_ids
end

#statusGoogle::Apis::AdminReportsV1::ActivityEventsStatus

Status of the event. Note: Not all events have status. Corresponds to the JSON property status



246
247
248
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 246

def status
  @status
end

#typeString

Type of event. The Google Workspace service or feature that an administrator changes is identified in the type property which identifies an event using the eventName property. For a full list of the API's type categories, see the list of event names for various applications above in applicationName. Corresponds to the JSON property type

Returns:

  • (String)


254
255
256
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 254

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



261
262
263
264
265
266
267
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 261

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @resource_ids = args[:resource_ids] if args.key?(:resource_ids)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end