Class: Google::Apis::AdminReportsV1::Activity::Event::Parameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb

Defined Under Namespace

Classes: MessageValue, MultiMessageValue

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Parameter

Returns a new instance of Parameter.



317
318
319
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Boolean value of the parameter. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


276
277
278
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 276

def bool_value
  @bool_value
end

#int_valueFixnum

Integer value of the parameter. Corresponds to the JSON property intValue

Returns:

  • (Fixnum)


282
283
284
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 282

def int_value
  @int_value
end

#message_valueGoogle::Apis::AdminReportsV1::Activity::Event::Parameter::MessageValue

Nested parameter value pairs associated with this parameter. Complex value type for a parameter are returned as a list of parameter values. For example, the address parameter may have a value as [parameter: [name: city, value: abc]] Corresponds to the JSON property messageValue



290
291
292
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 290

def message_value
  @message_value
end

#multi_int_valueArray<Fixnum>

Integer values of the parameter. Corresponds to the JSON property multiIntValue

Returns:

  • (Array<Fixnum>)


295
296
297
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 295

def multi_int_value
  @multi_int_value
end

#multi_message_valueArray<Google::Apis::AdminReportsV1::Activity::Event::Parameter::MultiMessageValue>

List of messageValue objects. Corresponds to the JSON property multiMessageValue



300
301
302
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 300

def multi_message_value
  @multi_message_value
end

#multi_valueArray<String>

String values of the parameter. Corresponds to the JSON property multiValue

Returns:

  • (Array<String>)


305
306
307
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 305

def multi_value
  @multi_value
end

#nameString

The name of the parameter. Corresponds to the JSON property name

Returns:

  • (String)


310
311
312
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 310

def name
  @name
end

#valueString

String value of the parameter. Corresponds to the JSON property value

Returns:

  • (String)


315
316
317
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 315

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



322
323
324
325
326
327
328
329
330
331
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 322

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @int_value = args[:int_value] if args.key?(:int_value)
  @message_value = args[:message_value] if args.key?(:message_value)
  @multi_int_value = args[:multi_int_value] if args.key?(:multi_int_value)
  @multi_message_value = args[:multi_message_value] if args.key?(:multi_message_value)
  @multi_value = args[:multi_value] if args.key?(:multi_value)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end