Class: Google::Apis::AdminReportsV1::Channel
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::Channel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Overview
A notification channel used to watch for resource changes.
Instance Attribute Summary collapse
-
#address ⇒ String
The address where notifications are delivered for this channel.
-
#expiration ⇒ Fixnum
Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds.
-
#id ⇒ String
A UUID or similar unique string that identifies this channel.
-
#kind ⇒ String
Identifies this as a notification channel used to watch for changes to a resource, which is "
api#channel". -
#params ⇒ Hash<String,String>
Additional parameters controlling delivery channel behavior.
-
#payload ⇒ Boolean
(also: #payload?)
A Boolean value to indicate whether payload is wanted.
-
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel.
-
#resource_uri ⇒ String
A version-specific identifier for the watched resource.
-
#token ⇒ String
An arbitrary string delivered to the target address with each notification delivered over this channel.
-
#type ⇒ String
The type of delivery mechanism used for this channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Channel
constructor
A new instance of Channel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Channel
Returns a new instance of Channel.
805 806 807 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 805 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The address where notifications are delivered for this channel.
Corresponds to the JSON property address
750 751 752 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 750 def address @address end |
#expiration ⇒ Fixnum
Date and time of notification channel expiration, expressed as a Unix
timestamp, in milliseconds. Optional.
Corresponds to the JSON property expiration
756 757 758 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 756 def expiration @expiration end |
#id ⇒ String
A UUID or similar unique string that identifies this channel.
Corresponds to the JSON property id
761 762 763 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 761 def id @id end |
#kind ⇒ String
Identifies this as a notification channel used to watch for changes to a
resource, which is "api#channel".
Corresponds to the JSON property kind
767 768 769 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 767 def kind @kind end |
#params ⇒ Hash<String,String>
Additional parameters controlling delivery channel behavior. Optional.
Corresponds to the JSON property params
772 773 774 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 772 def params @params end |
#payload ⇒ Boolean Also known as: payload?
A Boolean value to indicate whether payload is wanted. A payload is data that
is sent in the body of an HTTP POST, PUT, or PATCH message and contains
important information about the request. Optional.
Corresponds to the JSON property payload
779 780 781 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 779 def payload @payload end |
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel.
Stable across different API versions.
Corresponds to the JSON property resourceId
786 787 788 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 786 def resource_id @resource_id end |
#resource_uri ⇒ String
A version-specific identifier for the watched resource.
Corresponds to the JSON property resourceUri
791 792 793 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 791 def resource_uri @resource_uri end |
#token ⇒ String
An arbitrary string delivered to the target address with each notification
delivered over this channel. Optional.
Corresponds to the JSON property token
797 798 799 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 797 def token @token end |
#type ⇒ String
The type of delivery mechanism used for this channel. The value should be set
to "web_hook".
Corresponds to the JSON property type
803 804 805 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 803 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
810 811 812 813 814 815 816 817 818 819 820 821 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 810 def update!(**args) @address = args[:address] if args.key?(:address) @expiration = args[:expiration] if args.key?(:expiration) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @params = args[:params] if args.key?(:params) @payload = args[:payload] if args.key?(:payload) @resource_id = args[:resource_id] if args.key?(:resource_id) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @token = args[:token] if args.key?(:token) @type = args[:type] if args.key?(:type) end |