Class: Google::Apis::AdminReportsV1::Channel
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::Channel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Overview
A notification channel used to watch for resource changes.
Instance Attribute Summary collapse
-
#address ⇒ String
The address where notifications are delivered for this channel.
-
#expiration ⇒ Fixnum
Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds.
-
#id ⇒ String
A UUID or similar unique string that identifies this channel.
-
#kind ⇒ String
Identifies this as a notification channel used to watch for changes to a resource, which is "
api#channel". -
#params ⇒ Hash<String,String>
Additional parameters controlling delivery channel behavior.
-
#payload ⇒ Boolean
(also: #payload?)
A Boolean value to indicate whether payload is wanted.
-
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel.
-
#resource_uri ⇒ String
A version-specific identifier for the watched resource.
-
#token ⇒ String
An arbitrary string delivered to the target address with each notification delivered over this channel.
-
#type ⇒ String
The type of delivery mechanism used for this channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Channel
constructor
A new instance of Channel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Channel
Returns a new instance of Channel.
699 700 701 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The address where notifications are delivered for this channel.
Corresponds to the JSON property address
644 645 646 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 644 def address @address end |
#expiration ⇒ Fixnum
Date and time of notification channel expiration, expressed as a Unix
timestamp, in milliseconds. Optional.
Corresponds to the JSON property expiration
650 651 652 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 650 def expiration @expiration end |
#id ⇒ String
A UUID or similar unique string that identifies this channel.
Corresponds to the JSON property id
655 656 657 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 655 def id @id end |
#kind ⇒ String
Identifies this as a notification channel used to watch for changes to a
resource, which is "api#channel".
Corresponds to the JSON property kind
661 662 663 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 661 def kind @kind end |
#params ⇒ Hash<String,String>
Additional parameters controlling delivery channel behavior. Optional.
Corresponds to the JSON property params
666 667 668 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 666 def params @params end |
#payload ⇒ Boolean Also known as: payload?
A Boolean value to indicate whether payload is wanted. A payload is data that
is sent in the body of an HTTP POST, PUT, or PATCH message and contains
important information about the request. Optional.
Corresponds to the JSON property payload
673 674 675 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 673 def payload @payload end |
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel.
Stable across different API versions.
Corresponds to the JSON property resourceId
680 681 682 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 680 def resource_id @resource_id end |
#resource_uri ⇒ String
A version-specific identifier for the watched resource.
Corresponds to the JSON property resourceUri
685 686 687 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 685 def resource_uri @resource_uri end |
#token ⇒ String
An arbitrary string delivered to the target address with each notification
delivered over this channel. Optional.
Corresponds to the JSON property token
691 692 693 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 691 def token @token end |
#type ⇒ String
The type of delivery mechanism used for this channel. The value should be set
to "web_hook".
Corresponds to the JSON property type
697 698 699 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 697 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
704 705 706 707 708 709 710 711 712 713 714 715 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 704 def update!(**args) @address = args[:address] if args.key?(:address) @expiration = args[:expiration] if args.key?(:expiration) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @params = args[:params] if args.key?(:params) @payload = args[:payload] if args.key?(:payload) @resource_id = args[:resource_id] if args.key?(:resource_id) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @token = args[:token] if args.key?(:token) @type = args[:type] if args.key?(:type) end |