Class: Google::Apis::AdminReportsV1::FieldValue
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::FieldValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Overview
Details of the field value set by the user for the particular label.
Instance Attribute Summary collapse
-
#date_value ⇒ Google::Apis::AdminReportsV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#display_name ⇒ String
Display name of the field Corresponds to the JSON property
displayName. -
#id ⇒ String
Identifier of the field Corresponds to the JSON property
id. -
#integer_value ⇒ Fixnum
Setting an integer value.
-
#long_text_value ⇒ String
Setting a long text value.
-
#reason ⇒ Google::Apis::AdminReportsV1::Reason
The reason why the label/field was applied.
-
#selection_list_value ⇒ Google::Apis::AdminReportsV1::FieldValueSelectionListValue
Setting a selection list value by selecting multiple values from a dropdown.
-
#selection_value ⇒ Google::Apis::AdminReportsV1::FieldValueSelectionValue
Setting a selection value by selecting a single value from a dropdown.
-
#text_list_value ⇒ Google::Apis::AdminReportsV1::FieldValueTextListValue
Setting a text list value.
-
#text_value ⇒ String
Setting a text value.
-
#type ⇒ String
Type of the field Corresponds to the JSON property
type. -
#unset_value ⇒ Boolean
(also: #unset_value?)
If the field is unset, this will be true.
-
#user_list_value ⇒ Google::Apis::AdminReportsV1::FieldValueUserListValue
Setting a user list value by selecting multiple users.
-
#user_value ⇒ Google::Apis::AdminReportsV1::FieldValueUserValue
Setting a user value by selecting a single user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FieldValue
constructor
A new instance of FieldValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FieldValue
Returns a new instance of FieldValue.
729 730 731 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 729 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date_value ⇒ Google::Apis::AdminReportsV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property dateValue
661 662 663 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 661 def date_value @date_value end |
#display_name ⇒ String
Display name of the field
Corresponds to the JSON property displayName
666 667 668 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 666 def display_name @display_name end |
#id ⇒ String
Identifier of the field
Corresponds to the JSON property id
671 672 673 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 671 def id @id end |
#integer_value ⇒ Fixnum
Setting an integer value.
Corresponds to the JSON property integerValue
676 677 678 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 676 def integer_value @integer_value end |
#long_text_value ⇒ String
Setting a long text value.
Corresponds to the JSON property longTextValue
681 682 683 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 681 def long_text_value @long_text_value end |
#reason ⇒ Google::Apis::AdminReportsV1::Reason
The reason why the label/field was applied.
Corresponds to the JSON property reason
686 687 688 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 686 def reason @reason end |
#selection_list_value ⇒ Google::Apis::AdminReportsV1::FieldValueSelectionListValue
Setting a selection list value by selecting multiple values from a dropdown.
Corresponds to the JSON property selectionListValue
691 692 693 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 691 def selection_list_value @selection_list_value end |
#selection_value ⇒ Google::Apis::AdminReportsV1::FieldValueSelectionValue
Setting a selection value by selecting a single value from a dropdown.
Corresponds to the JSON property selectionValue
696 697 698 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 696 def selection_value @selection_value end |
#text_list_value ⇒ Google::Apis::AdminReportsV1::FieldValueTextListValue
Setting a text list value.
Corresponds to the JSON property textListValue
701 702 703 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 701 def text_list_value @text_list_value end |
#text_value ⇒ String
Setting a text value.
Corresponds to the JSON property textValue
706 707 708 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 706 def text_value @text_value end |
#type ⇒ String
Type of the field
Corresponds to the JSON property type
711 712 713 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 711 def type @type end |
#unset_value ⇒ Boolean Also known as: unset_value?
If the field is unset, this will be true.
Corresponds to the JSON property unsetValue
716 717 718 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 716 def unset_value @unset_value end |
#user_list_value ⇒ Google::Apis::AdminReportsV1::FieldValueUserListValue
Setting a user list value by selecting multiple users.
Corresponds to the JSON property userListValue
722 723 724 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 722 def user_list_value @user_list_value end |
#user_value ⇒ Google::Apis::AdminReportsV1::FieldValueUserValue
Setting a user value by selecting a single user.
Corresponds to the JSON property userValue
727 728 729 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 727 def user_value @user_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 734 def update!(**args) @date_value = args[:date_value] if args.key?(:date_value) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @integer_value = args[:integer_value] if args.key?(:integer_value) @long_text_value = args[:long_text_value] if args.key?(:long_text_value) @reason = args[:reason] if args.key?(:reason) @selection_list_value = args[:selection_list_value] if args.key?(:selection_list_value) @selection_value = args[:selection_value] if args.key?(:selection_value) @text_list_value = args[:text_list_value] if args.key?(:text_list_value) @text_value = args[:text_value] if args.key?(:text_value) @type = args[:type] if args.key?(:type) @unset_value = args[:unset_value] if args.key?(:unset_value) @user_list_value = args[:user_list_value] if args.key?(:user_list_value) @user_value = args[:user_value] if args.key?(:user_value) end |