Class: Google::Apis::AdminReportsV1::OwnerIdentity
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::OwnerIdentity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Overview
Identity details of the owner of the resource.
Instance Attribute Summary collapse
-
#customer_identity ⇒ Google::Apis::AdminReportsV1::CustomerIdentity
Identity of the Google Workspace customer who owns the resource.
-
#group_identity ⇒ Google::Apis::AdminReportsV1::GroupIdentity
Identity of the group who owns the resource.
-
#user_identity ⇒ Google::Apis::AdminReportsV1::UserIdentity
Identity of the user who owns the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OwnerIdentity
constructor
A new instance of OwnerIdentity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OwnerIdentity
Returns a new instance of OwnerIdentity.
1116 1117 1118 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_identity ⇒ Google::Apis::AdminReportsV1::CustomerIdentity
Identity of the Google Workspace customer who owns the resource.
Corresponds to the JSON property customerIdentity
1104 1105 1106 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1104 def customer_identity @customer_identity end |
#group_identity ⇒ Google::Apis::AdminReportsV1::GroupIdentity
Identity of the group who owns the resource.
Corresponds to the JSON property groupIdentity
1109 1110 1111 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1109 def group_identity @group_identity end |
#user_identity ⇒ Google::Apis::AdminReportsV1::UserIdentity
Identity of the user who owns the resource.
Corresponds to the JSON property userIdentity
1114 1115 1116 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1114 def user_identity @user_identity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1121 1122 1123 1124 1125 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1121 def update!(**args) @customer_identity = args[:customer_identity] if args.key?(:customer_identity) @group_identity = args[:group_identity] if args.key?(:group_identity) @user_identity = args[:user_identity] if args.key?(:user_identity) end |