Class: Google::Apis::AdminReportsV1::ResourceDetails
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::ResourceDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Overview
Details of the resource on which the action was performed.
Instance Attribute Summary collapse
-
#applied_labels ⇒ Array<Google::Apis::AdminReportsV1::AppliedLabel>
List of labels applied on the resource Corresponds to the JSON property
appliedLabels. -
#id ⇒ String
Identifier of the resource, such as a doc_id for a Drive document, a conference_id for a Meet conference, or a "gaia_id/rfc2822_message_id" for an email.
-
#owner_details ⇒ Google::Apis::AdminReportsV1::OwnerDetails
Details of the owner of the resource.
-
#relation ⇒ String
Defines relationship of the resource to the events Corresponds to the JSON property
relation. -
#title ⇒ String
Title of the resource.
-
#type ⇒ String
Type of the resource - document, email, chat message Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceDetails
constructor
A new instance of ResourceDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceDetails
Returns a new instance of ResourceDetails.
1184 1185 1186 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_labels ⇒ Array<Google::Apis::AdminReportsV1::AppliedLabel>
List of labels applied on the resource
Corresponds to the JSON property appliedLabels
1154 1155 1156 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1154 def applied_labels @applied_labels end |
#id ⇒ String
Identifier of the resource, such as a doc_id for a Drive document, a
conference_id for a Meet conference, or a "gaia_id/rfc2822_message_id" for an
email.
Corresponds to the JSON property id
1161 1162 1163 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1161 def id @id end |
#owner_details ⇒ Google::Apis::AdminReportsV1::OwnerDetails
Details of the owner of the resource.
Corresponds to the JSON property ownerDetails
1166 1167 1168 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1166 def owner_details @owner_details end |
#relation ⇒ String
Defines relationship of the resource to the events
Corresponds to the JSON property relation
1171 1172 1173 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1171 def relation @relation end |
#title ⇒ String
Title of the resource. For instance, in case of a drive document, this would
be the title of the document. In case of an email, this would be the subject.
Corresponds to the JSON property title
1177 1178 1179 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1177 def title @title end |
#type ⇒ String
Type of the resource - document, email, chat message
Corresponds to the JSON property type
1182 1183 1184 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1182 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1189 def update!(**args) @applied_labels = args[:applied_labels] if args.key?(:applied_labels) @id = args[:id] if args.key?(:id) @owner_details = args[:owner_details] if args.key?(:owner_details) @relation = args[:relation] if args.key?(:relation) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |