Class: Google::Apis::AdminReportsV1::ResourceDetails
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::ResourceDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Overview
Details of the resource on which the action was performed.
Instance Attribute Summary collapse
-
#applied_labels ⇒ Array<Google::Apis::AdminReportsV1::AppliedLabel>
List of labels applied on the resource Corresponds to the JSON property
appliedLabels. -
#id ⇒ String
Identifier of the resource.
-
#relation ⇒ String
Defines relationship of the resource to the events Corresponds to the JSON property
relation. -
#title ⇒ String
Title of the resource.
-
#type ⇒ String
Type of the resource - document, email, chat message Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceDetails
constructor
A new instance of ResourceDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceDetails
Returns a new instance of ResourceDetails.
965 966 967 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 965 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_labels ⇒ Array<Google::Apis::AdminReportsV1::AppliedLabel>
List of labels applied on the resource
Corresponds to the JSON property appliedLabels
942 943 944 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 942 def applied_labels @applied_labels end |
#id ⇒ String
Identifier of the resource.
Corresponds to the JSON property id
947 948 949 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 947 def id @id end |
#relation ⇒ String
Defines relationship of the resource to the events
Corresponds to the JSON property relation
952 953 954 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 952 def relation @relation end |
#title ⇒ String
Title of the resource. For instance, in case of a drive document, this would
be the title of the document. In case of an email, this would be the subject.
Corresponds to the JSON property title
958 959 960 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 958 def title @title end |
#type ⇒ String
Type of the resource - document, email, chat message
Corresponds to the JSON property type
963 964 965 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 963 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
970 971 972 973 974 975 976 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 970 def update!(**args) @applied_labels = args[:applied_labels] if args.key?(:applied_labels) @id = args[:id] if args.key?(:id) @relation = args[:relation] if args.key?(:relation) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |