Class: Google::Apis::AdminReportsV1::UsageReports::Warning::Datum
- Inherits:
-
Object
- Object
- Google::Apis::AdminReportsV1::UsageReports::Warning::Datum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_reports_v1/classes.rb,
lib/google/apis/admin_reports_v1/representations.rb,
lib/google/apis/admin_reports_v1/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
Key associated with a key-value pair to give detailed information on the warning.
-
#value ⇒ String
Value associated with a key-value pair to give detailed information on the warning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Datum
constructor
A new instance of Datum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Datum
Returns a new instance of Datum.
1218 1219 1220 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Key associated with a key-value pair to give detailed information on the
warning.
Corresponds to the JSON property key
1210 1211 1212 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1210 def key @key end |
#value ⇒ String
Value associated with a key-value pair to give detailed information on the
warning.
Corresponds to the JSON property value
1216 1217 1218 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1216 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1223 1224 1225 1226 |
# File 'lib/google/apis/admin_reports_v1/classes.rb', line 1223 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |